==> 1.2.9.tar.gz: lib/src/extensions/color.dart <==
import 'dart:math' as math;

import 'package:flutter/material.dart';

extension ColorExt on Color {
  /// Get HSLColor from this color
  HSLColor toHSLColor() => this == Colors.black ? HSLColor.fromColor(this).withSaturation(0) : HSLColor.fromColor(this);

  /// Darkens the color with the given integer percentage amount.
  Color darken(double amount) => lighten(-amount);

  /// Lightens the color with the given integer percentage amount.
  Color lighten(double amount) {
    final hsl = toHSLColor();
    return hsl.withLightness((hsl.lightness + amount).clamp(0, 1)).toColor();
  }

  /// Brightens the color with the given integer percentage amount.
  Color brighten(double amount) => Color.fromARGB(alpha, (red + (255 * amount).round()).clamp(0, 255),
      (green + (255 * amount).round()).clamp(0, 255), (blue + (255 * amount).round()).clamp(0, 255));

  /// Blend in the given [input] Color with a percentage amount.
  Color blend(Color input, double amount) => Color.fromARGB(
      _lerpInt(alpha, input.alpha, amount).clamp(0, 255),
      _lerpInt(red, input.red, amount).clamp(0, 255),
      _lerpInt(green, input.green, amount).clamp(0, 255),
      _lerpInt(blue, input.blue, amount).clamp(0, 255));

  /// Compute RGB difference between this and other and returns delta
  double differenceRGB(Color other) =>
      math.sqrt(math.pow(other.red - red, 2) + math.pow(other.green - green, 2) + math.pow(other.blue - blue, 2));

  /// Short alias for [differenceRGB]
  double operator -(Color other) => differenceRGB(other);

  /// Get negative color in RGB scale
  Color get negative => Color.fromARGB(alpha, 255 - red, 255 - green, 255 - blue);

  /// returns brightness of this color based on luminance
  Brightness get brightness => ThemeData.estimateBrightnessForColor(this);

  /// returns HEX string representing this color e.g. FF00BB11
  String get hexString => value.toRadixString(16).padLeft(8, '0').toUpperCase();

  int _lerpInt(int a, int b, double t) => (a + (b - a) * t).round();
}

==> 1.3.8.tar.gz: lib/src/extensions/color.dart <==
import 'dart:math' as math;

import 'package:flutter/material.dart';

extension ColorExt on Color {
  /// Get HSLColor from this color
  HSLColor toHSLColor() => this == Colors.black ? HSLColor.fromColor(this).withSaturation(0) : HSLColor.fromColor(this);

  /// Darkens the color with the given integer percentage amount.
  Color darken(double amount) => lighten(-amount);

  /// Lightens the color with the given integer percentage amount.
  Color lighten(double amount) {
    final hsl = toHSLColor();
    return hsl.withLightness((hsl.lightness + amount).clamp(0, 1)).toColor();
  }

  /// Brightens the color with the given integer percentage amount.
  Color brighten(double amount) => Color.fromARGB(alpha, (red + (255 * amount).round()).clamp(0, 255),
      (green + (255 * amount).round()).clamp(0, 255), (blue + (255 * amount).round()).clamp(0, 255));

  /// Blend in the given [input] Color with a percentage amount.
  Color blend(Color input, double amount) => amount == 0
      ? this
      : amount == 1
          ? input
          : Color.fromARGB(
              _lerpInt(alpha, input.alpha, amount).clamp(0, 255),
              _lerpInt(red, input.red, amount).clamp(0, 255),
              _lerpInt(green, input.green, amount).clamp(0, 255),
              _lerpInt(blue, input.blue, amount).clamp(0, 255));

  /// Compute RGB difference between this and other and returns delta
  double differenceRGB(Color other) =>
      math.sqrt(math.pow(other.red - red, 2) + math.pow(other.green - green, 2) + math.pow(other.blue - blue, 2));

  /// Short alias for [differenceRGB]
  double operator -(Color other) => differenceRGB(other);

  /// Get negative color in RGB scale
  Color get negative => Color.fromARGB(alpha, 255 - red, 255 - green, 255 - blue);

  /// returns brightness of this color based on luminance
  Brightness get brightness => ThemeData.estimateBrightnessForColor(this);

  /// returns HEX string representing this color e.g. FF00BB11
  String get hexString => value.toRadixString(16).padLeft(8, '0').toUpperCase();

  static int _lerpInt(int a, int b, double t) => (a + (b - a) * t).round();
}
